file

Function file 

pub fn file(target: &Path, link: &Path) -> Result<()>
Create a symbolic link whose target is a file.

Windows requires the file-target intent. The same intent is explicit on every platform. The target need not exist when the link is created.

Errors

Returns a contextual error when the platform cannot create the link.